# Projects Using Torii

The following is an incomplete list of projects that use Torii, we'd love to add yours to this list too! [submit pull request](https://github.com/shrine-maiden-heavy-industries/torii-hdl/pulls) or an [issue](https://github.com/shrine-maiden-heavy-industries/torii-hdl/issues) so we can add it!

* [Squishy](https://github.com/lethalbit/squishy) - A SCSI Multitool and framework
* [SOL](https://github.com/shrine-maiden-heavy-industries/sol) - A framework for developing USB-enabled gateware
